@@ -49,6 +49,7 @@ struct OBSStudioAPI : obs_frontend_callbacks {
 	OBSBasic *main;
 	vector<OBSStudioCallback<obs_frontend_event_cb>> callbacks;
 	vector<OBSStudioCallback<obs_frontend_save_cb>> saveCallbacks;
+	vector<OBSStudioCallback<obs_frontend_save_cb>> preloadCallbacks;
 
 	inline OBSStudioAPI(OBSBasic *main_) : main(main_) {}
 
@@ -239,6 +240,11 @@ struct OBSStudioAPI : obs_frontend_callbacks {
 		QMetaObject::invokeMethod(main, "StartReplayBuffer");
 	}
 
+	void obs_frontend_replay_buffer_save(void) override
+	{
+		QMetaObject::invokeMethod(main, "ReplayBufferSave");
+	}
+
 	void obs_frontend_replay_buffer_stop(void) override
 	{
 		QMetaObject::invokeMethod(main, "StopReplayBuffer");
@@ -343,6 +349,26 @@ struct OBSStudioAPI : obs_frontend_callbacks {
 		saveCallbacks.erase(saveCallbacks.begin() + idx);
 	}
 
+	void obs_frontend_add_preload_callback(obs_frontend_save_cb callback,
+			void *private_data) override
+	{
+		size_t idx = GetCallbackIdx(preloadCallbacks, callback,
+				private_data);
+		if (idx == (size_t)-1)
+			preloadCallbacks.emplace_back(callback, private_data);
+	}
+
+	void obs_frontend_remove_preload_callback(obs_frontend_save_cb callback,
+			void *private_data) override
+	{
+		size_t idx = GetCallbackIdx(preloadCallbacks, callback,
+				private_data);
+		if (idx == (size_t)-1)
+			return;
+
+		preloadCallbacks.erase(preloadCallbacks.begin() + idx);
+	}
+
 	void obs_frontend_push_ui_translation(
 			obs_frontend_translate_ui_cb translate) override
 	{
@@ -379,6 +405,17 @@ struct OBSStudioAPI : obs_frontend_callbacks {
 		main->SetPreviewProgramMode(enable);
 	}
 
+	bool obs_frontend_preview_enabled(void) override
+	{
+		return main->previewEnabled;
+	}
+
+	void obs_frontend_set_preview_enabled(bool enable) override
+	{
+		if (main->previewEnabled != enable)
+			main->EnablePreviewDisplay(enable);
+	}
+
 	obs_source_t *obs_frontend_get_current_preview_scene(void) override
 	{
 		OBSSource source = nullptr;
@@ -402,14 +439,26 @@ struct OBSStudioAPI : obs_frontend_callbacks {
 
 	void on_load(obs_data_t *settings) override
 	{
-		for (auto cb : saveCallbacks)
+		for (size_t i = saveCallbacks.size(); i > 0; i--) {
+			auto cb = saveCallbacks[i - 1];
 			cb.callback(settings, false, cb.private_data);
+		}
+	}
+
+	void on_preload(obs_data_t *settings) override
+	{
+		for (size_t i = preloadCallbacks.size(); i > 0; i--) {
+			auto cb = preloadCallbacks[i - 1];
+			cb.callback(settings, false, cb.private_data);
+		}
 	}
 
 	void on_save(obs_data_t *settings) override
 	{
-		for (auto cb : saveCallbacks)
+		for (size_t i = saveCallbacks.size(); i > 0; i--) {
+			auto cb = saveCallbacks[i - 1];
 			cb.callback(settings, true, cb.private_data);
+		}
 	}
 
 	void on_event(enum obs_frontend_event event) override
@@ -417,8 +466,10 @@ struct OBSStudioAPI : obs_frontend_callbacks {
 		if (main->disableSaving)
 			return;
 
-		for (auto cb : callbacks)
+		for (size_t i = callbacks.size(); i > 0; i--) {
+			auto cb = callbacks[i - 1];
 			cb.callback(event, cb.private_data);
+		}
 	}
 };
 
