@@ -158,6 +158,7 @@ inline OBSSource OBSBasicFilters::GetFilter(int row, bool async)
 void OBSBasicFilters::UpdatePropertiesView(int row, bool async)
 {
 	if (view) {
+		updatePropertiesSignal.Disconnect();
 		ui->rightLayout->removeWidget(view);
 		view->deleteLater();
 		view = nullptr;
@@ -173,6 +174,11 @@ void OBSBasicFilters::UpdatePropertiesView(int row, bool async)
 			(PropertiesReloadCallback)obs_source_properties,
 			(PropertiesUpdateCallback)obs_source_update);
 
+	updatePropertiesSignal.Connect(obs_source_get_signal_handler(filter),
+			"update_properties",
+			OBSBasicFilters::UpdateProperties,
+			this);
+
 	obs_data_release(settings);
 
 	view->setMaximumHeight(250);
@@ -181,6 +187,12 @@ void OBSBasicFilters::UpdatePropertiesView(int row, bool async)
 	view->show();
 }
 
+void OBSBasicFilters::UpdateProperties(void *data, calldata_t *)
+{
+	QMetaObject::invokeMethod(static_cast<OBSBasicFilters*>(data)->view,
+			"ReloadProperties");
+}
+
 void OBSBasicFilters::AddFilter(OBSSource filter)
 {
 	uint32_t flags = obs_source_get_output_flags(filter);
@@ -349,6 +361,12 @@ QMenu *OBSBasicFilters::CreateAddFilterPopupMenu(bool async)
 	vector<FilterInfo> types;
 	while (obs_enum_filter_types(idx++, &type_str)) {
 		const char *name = obs_source_get_display_name(type_str);
+		uint32_t caps = obs_get_source_output_flags(type_str);
+
+		if ((caps & OBS_SOURCE_DEPRECATED) != 0)
+			continue;
+		if ((caps & OBS_SOURCE_CAP_DISABLED) != 0)
+			continue;
 
 		auto it = types.begin();
 		for (; it != types.end(); ++it) {
