@@ -1,5 +1,7 @@
 #pragma once
 
+#include <util/darray.h>
+
 struct update_info;
 typedef struct update_info update_info_t;
 
@@ -21,4 +23,10 @@ update_info_t *update_info_create(
 		const char *cache_dir,
 		confirm_file_callback_t confirm_callback,
 		void *param);
+update_info_t *update_info_create_single(
+		const char *log_prefix,
+		const char *user_agent,
+		const char *file_url,
+		confirm_file_callback_t confirm_callback,
+		void *param);
 void update_info_destroy(update_info_t *info);
