@@ -30,7 +30,7 @@ struct ShaderProcessor {
 
 	void BuildInputLayout(vector<D3D11_INPUT_ELEMENT_DESC> &inputs);
 	void BuildParams(vector<gs_shader_param> &params);
-	void BuildSamplers(vector<ShaderSampler> &samplers);
+	void BuildSamplers(vector<unique_ptr<ShaderSampler>> &samplers);
 	void BuildString(string &outputString);
 	void Process(const char *shader_string, const char *file);
 
