@@ -63,6 +63,12 @@ static bool gl_write_type_n(struct gl_shader_parser *glsp,
 		dstr_cat(&glsp->gl_string, "vec3");
 	else if (cmp_type(type, len, "float4", 6) == 0)
 		dstr_cat(&glsp->gl_string, "vec4");
+	else if (cmp_type(type, len, "int2", 4) == 0)
+		dstr_cat(&glsp->gl_string, "ivec2");
+	else if (cmp_type(type, len, "int3", 4) == 0)
+		dstr_cat(&glsp->gl_string, "ivec3");
+	else if (cmp_type(type, len, "int4", 4) == 0)
+		dstr_cat(&glsp->gl_string, "ivec4");
 	else if (cmp_type(type, len, "float3x3", 8) == 0)
 		dstr_cat(&glsp->gl_string, "mat3x3");
 	else if (cmp_type(type, len, "float3x4", 8) == 0)
@@ -294,20 +300,21 @@ static bool gl_write_saturate(struct gl_shader_parser *glsp,
 }
 
 static inline bool gl_write_texture_call(struct gl_shader_parser *glsp,
-		struct shader_var *var, const char *call)
+		struct shader_var *var, const char *call, bool sampler)
 {
 	struct cf_parser *cfp = &glsp->parser.cfp;
 	size_t sampler_id = (size_t)-1;
 
 	if (!cf_next_token(cfp))    return false;
 	if (!cf_token_is(cfp, "(")) return false;
-	if (!cf_next_token(cfp))    return false;
 
-	sampler_id = sp_getsampler(glsp, cfp->cur_token);
-	if (sampler_id == (size_t)-1) return false;
-
-	if (!cf_next_token(cfp))    return false;
-	if (!cf_token_is(cfp, ",")) return false;
+	if (sampler) {
+		if (!cf_next_token(cfp))    return false;
+		sampler_id = sp_getsampler(glsp, cfp->cur_token);
+		if (sampler_id == (size_t) -1) return false;
+		if (!cf_next_token(cfp))    return false;
+		if (!cf_token_is(cfp, ",")) return false;
+	}
 
 	var->gl_sampler_id = sampler_id;
 
@@ -330,14 +337,21 @@ static bool gl_write_texture_code(struct gl_shader_parser *glsp,
 	if (!cf_token_is(cfp, ".")) return false;
 	if (!cf_next_token(cfp))    return false;
 
+	const char *function_end = ")";
+
 	if (cf_token_is(cfp, "Sample"))
-		written = gl_write_texture_call(glsp, var, "texture");
+		written = gl_write_texture_call(glsp, var, "texture", true);
 	else if (cf_token_is(cfp, "SampleBias"))
-		written = gl_write_texture_call(glsp, var, "texture");
+		written = gl_write_texture_call(glsp, var, "texture", true);
 	else if (cf_token_is(cfp, "SampleGrad"))
-		written = gl_write_texture_call(glsp, var, "textureGrad");
+		written = gl_write_texture_call(glsp, var, "textureGrad", true);
 	else if (cf_token_is(cfp, "SampleLevel"))
-		written = gl_write_texture_call(glsp, var, "textureLod");
+		written = gl_write_texture_call(glsp, var, "textureLod", true);
+	else if (cf_token_is(cfp, "Load")) {
+		written = gl_write_texture_call(glsp, var, "texelFetch", false);
+		dstr_cat(&glsp->gl_string, "(");
+		function_end = ").xy, 0)";
+	}
 
 	if (!written)
 		return false;
@@ -345,7 +359,7 @@ static bool gl_write_texture_code(struct gl_shader_parser *glsp,
 	if (!cf_next_token(cfp)) return false;
 
 	gl_write_function_contents(glsp, &cfp->cur_token, ")");
-	dstr_cat(&glsp->gl_string, ")");
+	dstr_cat(&glsp->gl_string, function_end);
 
 	*p_token = cfp->cur_token;
 	return true;
