@@ -20,3 +20,12 @@
 # define av_frame_free avcodec_free_frame
 #endif
 
+#if LIBAVCODEC_VERSION_MAJOR >= 58
+#define CODEC_CAP_TRUNC AV_CODEC_CAP_TRUNCATED
+#define CODEC_FLAG_TRUNC AV_CODEC_FLAG_TRUNCATED
+#define INPUT_BUFFER_PADDING_SIZE AV_INPUT_BUFFER_PADDING_SIZE
+#else
+#define CODEC_CAP_TRUNC CODEC_CAP_TRUNCATED
+#define CODEC_FLAG_TRUNC CODEC_FLAG_TRUNCATED
+#define INPUT_BUFFER_PADDING_SIZE FF_INPUT_BUFFER_PADDING_SIZE
+#endif
