@@ -38,9 +38,24 @@ static uint64_t tick_sources(uint64_t cur_time, uint64_t last_time)
 	delta_time = cur_time - last_time;
 	seconds = (float)((double)delta_time / 1000000000.0);
 
+	/* ------------------------------------- */
+	/* call tick callbacks                   */
+
+	pthread_mutex_lock(&obs->data.draw_callbacks_mutex);
+
+	for (size_t i = obs->data.tick_callbacks.num; i > 0; i--) {
+		struct tick_callback *callback;
+		callback = obs->data.tick_callbacks.array + (i - 1);
+		callback->tick(callback->param, seconds);
+	}
+
+	pthread_mutex_unlock(&obs->data.draw_callbacks_mutex);
+
+	/* ------------------------------------- */
+	/* call the tick function of each source */
+
 	pthread_mutex_lock(&data->sources_mutex);
 
-	/* call the tick function of each source */
 	source = data->first_source;
 	while (source) {
 		obs_source_video_tick(source, seconds);
@@ -111,9 +126,9 @@ static inline void render_main_texture(struct obs_core_video *video,
 
 	pthread_mutex_lock(&obs->data.draw_callbacks_mutex);
 
-	for (size_t i = 0; i < obs->data.draw_callbacks.num; i++) {
+	for (size_t i = obs->data.draw_callbacks.num; i > 0; i--) {
 		struct draw_callback *callback;
-		callback = obs->data.draw_callbacks.array+i;
+		callback = obs->data.draw_callbacks.array + (i - 1);
 
 		callback->draw(callback->param,
 				video->base_width, video->base_height);
@@ -614,14 +629,14 @@ void *obs_graphics_thread(void *param)
 		last_time = tick_sources(obs->video.video_time, last_time);
 		profile_end(tick_sources_name);
 
-		profile_start(render_displays_name);
-		render_displays();
-		profile_end(render_displays_name);
-
 		profile_start(output_frame_name);
 		output_frame();
 		profile_end(output_frame_name);
 
+		profile_start(render_displays_name);
+		render_displays();
+		profile_end(render_displays_name);
+
 		frame_time_ns = os_gettime_ns() - frame_start;
 
 		profile_end(video_thread_name);
