@@ -26,8 +26,11 @@ struct audio_repack {
 };
 
 enum _audio_repack_mode {
+	repack_mode_8to3ch_swap23,
+	repack_mode_8to4ch_swap23,
+	repack_mode_8to5ch_swap23,
 	repack_mode_8to6ch_swap23,
-	repack_mode_8ch_swap23,
+	repack_mode_8ch_swap23_swap46_swap57,
 };
 
 typedef enum _audio_repack_mode audio_repack_mode_t;
