@@ -32,6 +32,14 @@ BMDDisplayMode DeckLinkDeviceMode::GetDisplayMode(void) const
 	return bmdModeUnknown;
 }
 
+BMDDisplayModeFlags DeckLinkDeviceMode::GetDisplayModeFlags(void) const
+{
+	if (mode != nullptr)
+		return mode->GetFlags();
+
+	return (BMDDisplayModeFlags)0;
+}
+
 long long DeckLinkDeviceMode::GetId(void) const
 {
 	return id;
@@ -41,3 +49,14 @@ const std::string& DeckLinkDeviceMode::GetName(void) const
 {
 	return name;
 }
+
+void DeckLinkDeviceMode::SetMode(IDeckLinkDisplayMode *mode_)
+{
+	IDeckLinkDisplayMode *old = mode;
+	if (old != nullptr)
+		old->Release();
+
+	mode = mode_;
+	if (mode != nullptr)
+		mode->AddRef();
+}
