@@ -31,7 +31,7 @@ public:
 	const std::string& GetHash(void) const;
 	const std::vector<DeckLinkDeviceMode *>& GetModes(void) const;
 	const std::string& GetName(void) const;
-	const int32_t GetMaxChannel(void) const;
+	int32_t GetMaxChannel(void) const;
 
 	bool GetInput(IDeckLinkInput **input);
 
