@@ -101,6 +101,13 @@ static const int v4l2_framesizes[] =
 	1600<<16	| 900,
 	1920<<16	| 1080,
 	1920<<16	| 1200,
+	2560<<16	| 1440,
+	3840<<16	| 2160,
+
+	/* 21:9 */
+	2560<<16	| 1080,
+	3440<<16	| 1440,
+	5120<<16	| 2160,
 
 	/* tv */
 	432<<16		| 520,
