@@ -11,6 +11,7 @@ extern struct obs_source_info gain_filter;
 extern struct obs_source_info color_filter;
 extern struct obs_source_info scale_filter;
 extern struct obs_source_info scroll_filter;
+extern struct obs_source_info gpu_delay_filter;
 extern struct obs_source_info color_key_filter;
 extern struct obs_source_info color_grade_filter;
 extern struct obs_source_info sharpness_filter;
@@ -30,6 +31,7 @@ bool obs_module_load(void)
 	obs_register_source(&color_filter);
 	obs_register_source(&scale_filter);
 	obs_register_source(&scroll_filter);
+	obs_register_source(&gpu_delay_filter);
 	obs_register_source(&color_key_filter);
 	obs_register_source(&color_grade_filter);
 	obs_register_source(&sharpness_filter);
