@@ -324,6 +324,8 @@ extern "C"
         RTMPPacket m_write;
         RTMPSockBuf m_sb;
         RTMP_LNK Link;
+        int connect_time_ms;
+        int last_error_code;
     } RTMP;
 
     int RTMP_ParseURL(const char *url, int *protocol, AVal *host,
